function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from "react";
import PropTypes from "prop-types";
import classNames from "classnames";
import Label from "../Label";
/**
 * Generates a `input` element of type `radio` that is wrapped in a `Label`.
 * @param {Object} props - Properties passed to component
 * @returns {ReactElement}
 */

var Radio = function Radio(_ref) {
  var checked = _ref.checked,
      className = _ref.className,
      defaultChecked = _ref.defaultChecked,
      isDisabled = _ref.isDisabled,
      label = _ref.label,
      labelWeight = _ref.labelWeight,
      name = _ref.name,
      onChange = _ref.onChange,
      _ref$testSection = _ref.testSection,
      testSection = _ref$testSection === void 0 ? null : _ref$testSection,
      props = _objectWithoutProperties(_ref, ["checked", "className", "defaultChecked", "isDisabled", "label", "labelWeight", "name", "onChange", "testSection"]);

  var labelClassNames = classNames({
    "flush--bottom": true,
    "push--left": true,
    "weight--light": labelWeight === "light",
    "weight--normal": labelWeight === "normal",
    "weight--bold": labelWeight === "bold",
    "cursor--pointer": true,
    "oui-label--disabled": isDisabled
  });
  var classes = classNames({
    "flex--none": true
  }, className);
  return React.createElement(Label, {
    "data-test-section": "".concat(testSection, "-label")
  }, React.createElement("div", {
    className: "flex"
  }, React.createElement("input", _extends({
    "data-oui-component": true,
    type: "radio",
    name: name,
    defaultChecked: defaultChecked,
    checked: checked,
    className: classes,
    disabled: isDisabled,
    onChange: onChange,
    "data-test-section": testSection,
    style: {
      marginTop: "0.3em"
    }
  }, props)), React.createElement("div", {
    className: labelClassNames
  }, label)));
};

Radio.propTypes = {
  /** Boolean to set radio input, for controlled component  */
  checked: PropTypes.bool,

  /** CSS class names. */
  className: PropTypes.string,

  /** Boolean for how radio input renders initially  */
  defaultChecked: PropTypes.bool,

  /** Prevents radio input from being modified and appears disabled */
  isDisabled: PropTypes.bool,

  /** Text that describes the radio input */
  label: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),

  /** Font weight for the label text */
  labelWeight: PropTypes.oneOf(["light", "normal", "bold"]),

  /**
  String that can be used to identify a set of radio inputs so that only one
  in the set is checked at any given time.
  */
  name: PropTypes.string.isRequired,

  /** Function that fires when the radio input is clicked */
  onChange: PropTypes.func,

  /** Hook for automated JavaScript tests */
  testSection: PropTypes.string
};
Radio.defaultProps = {
  labelWeight: "normal"
};
export default Radio;